summaryrefslogtreecommitdiffstats
path: root/net/http/http_transaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/http/http_transaction.h')
-rw-r--r--net/http/http_transaction.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/net/http/http_transaction.h b/net/http/http_transaction.h
index 8a0d25f..a18d422 100644
--- a/net/http/http_transaction.h
+++ b/net/http/http_transaction.h
@@ -12,10 +12,10 @@
namespace net {
+class BoundNetLog;
class HttpRequestInfo;
class HttpResponseInfo;
class IOBuffer;
-class LoadLog;
class X509Certificate;
// Represents a single HTTP transaction (i.e., a single request/response pair).
@@ -39,10 +39,10 @@ class HttpTransaction {
//
// NOTE: The transaction is not responsible for deleting the callback object.
//
// Profiling information for the request is saved to |load_log| if non-NULL.
virtual int Start(const HttpRequestInfo* request_info,
CompletionCallback* callback,
- LoadLog* load_log) = 0;
+ const BoundNetLog& net_log) = 0;
// Restarts the HTTP transaction, ignoring the last error. This call can
// only be made after a call to Start (or RestartIgnoringLastError) failed.
@@ -39,10 +39,10 @@ class HttpTransaction {
// NOTE: The transaction is not responsible for deleting the callback object.
//
- // Profiling information for the request is saved to |load_log| if non-NULL.
+ // Profiling information for the request is saved to |net_log| if non-NULL.
virtual int Start(const HttpRequestInfo* request_info,
CompletionCallback* callback,